aboutsummaryrefslogtreecommitdiff
path: root/src/google_breakpad/processor/source_line_resolver_interface.h
diff options
context:
space:
mode:
authorjimblandy <jimblandy@4c0a9323-5329-0410-9bdc-e9ce6186880e>2009-12-23 22:32:14 +0000
committerjimblandy <jimblandy@4c0a9323-5329-0410-9bdc-e9ce6186880e>2009-12-23 22:32:14 +0000
commitb64d76a3b8a692f431d440f6a4416e7c70aad4ef (patch)
tree1db2441d85576d3c33c354f105cf48703f218e9d /src/google_breakpad/processor/source_line_resolver_interface.h
parentBreakpad: Regenerate build files with latest versions of autotools. (diff)
downloadbreakpad-b64d76a3b8a692f431d440f6a4416e7c70aad4ef.tar.xz
Issue 49012: Breakpad Processor: Rename 'StackFrameInfo' structure to 'WindowsFrameInfo'.
Also, rename stack_frame_info.h to windows_frame_info.h. If it seems odd to have functions like FillSourceLineInfo returning Windows-specific data structures... well, it is! This patch just makes it more obvious what's going on. a=jimblandy, r=nealsid git-svn-id: http://google-breakpad.googlecode.com/svn/trunk@471 4c0a9323-5329-0410-9bdc-e9ce6186880e
Diffstat (limited to 'src/google_breakpad/processor/source_line_resolver_interface.h')
-rw-r--r--src/google_breakpad/processor/source_line_resolver_interface.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/google_breakpad/processor/source_line_resolver_interface.h b/src/google_breakpad/processor/source_line_resolver_interface.h
index 93ef85d2..a139cf07 100644
--- a/src/google_breakpad/processor/source_line_resolver_interface.h
+++ b/src/google_breakpad/processor/source_line_resolver_interface.h
@@ -40,7 +40,7 @@ namespace google_breakpad {
using std::string;
struct StackFrame;
-struct StackFrameInfo;
+struct WindowsFrameInfo;
class SourceLineResolverInterface {
public:
@@ -68,9 +68,9 @@ class SourceLineResolverInterface {
// module_name fields must already be filled in. Additional debugging
// information, if available, is returned. If the information is not
// available, returns NULL. A NULL return value does not indicate an
// error. The caller takes ownership of any returned StackFrameInfo
// object.
- virtual StackFrameInfo* FillSourceLineInfo(StackFrame *frame) const = 0;
+ virtual WindowsFrameInfo* FillSourceLineInfo(StackFrame *frame) const = 0;
protected:
// SourceLineResolverInterface cannot be instantiated except by subclasses
@@ -68,9 +68,9 @@ class SourceLineResolverInterface {
// information, if available, is returned. If the information is not
// available, returns NULL. A NULL return value does not indicate an
- // error. The caller takes ownership of any returned StackFrameInfo
+ // error. The caller takes ownership of any returned WindowsFrameInfo
// object.